---
title: 우커머스(with. 코드엠샵)지원 결제대행사 리스트
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 플러그인
tags:
  - 워드프레스
searchTags:
  - 코드엠샵
  - 플러그인
  - 워드프레스
datetime: 2024-06-19T07:23:36.830Z
---

<Callout content="워드프레스 우커머스 플러그인으로 웹사이트를 구축하시는 경우
이용 가능한 결제대행사와 연동방식이 구분되어있으니 참고하여 이용 부탁 드립니다." />

우커머스 지원 가능한 결제대행사 및 결제수단 입니다.

### 일반결제

<Indent level="1">

- KCP : 신용카드, 휴대폰 소액결제, 실시간 계좌이체, 가상계좌
- 이니시스 : 신용카드, 휴대폰 소액결제, 실시간 계좌이체, 가상계좌
- 토스페이먼츠: 신용카드, 실시간 계좌이체, 가상계좌
- 나이스페이먼츠 : 신용카드, 실시간 계좌이체, 가상계좌
- 키움페이 : 신용카드, 실시간 계좌이체, 가상계좌
- 다날 : 신용카드, 휴대폰 소액결제, 실시간 계좌이체, 가상계좌
- KICC : 신용카드, 실시간 계좌이체, 가상계좌
- 헥토파이낸셜 : 신용카드
- KSNET신용카드, 휴대폰 소액결제, 실시간 계좌이체, 가상계좌
- 웰컴페이먼츠 : 신용카드, 휴대폰 소액결제, 실시간 계좌이체, 가상계좌
- 스마트로 : 신용카드, 실시간 계좌이체, 가상계좌

</Indent>

### 정기결제

<Indent level="1">

- KCP : 결제창 방식, REST API 방식
- 이니시스 : 결제창 방식
- 토스페이먼츠 : 결제창 방식
- 나이스페이 : REST API 방식
- 다날 : 결제창 방식(신용카드, 휴대폰)
- 모빌리언스: 결제창 방식(휴대폰)
- 키움페이: REST API 방식
- 헥토파이낸셜 : REST API 방식
- KSNET : REST API 방식
- 스마트로 : 결제창 방식

</Indent>

### 간편결제

<Indent level="1">

- 카카오페이 : 신용카드 카카오머니
- 네이버페이 (결제형) :  허브형 간편결제 (직연동 불가)

</Indent>

### 해외결제

<Indent level="1">

- 엑심베이
- 페이먼트월

</Indent>

### 키인결제

<Indent level="1">

- 키인결제를 api 방식으로 지원하는 모든 PG

</Indent>

#### 참고 연동가이드

포트원을 통한 워드프레스 우커머스 플러그인 사용방법을 안내드립니다.

<Callout title="우커머스 플러그인 이용방법 보러가기 ↗" />
